@@ -276,7 +276,7 @@ const EmptyResultsBox = new Lang.Class({
         else if (this._mode == WindowMode.WindowMode.COLLECTIONS)
             iconName = 'emblem-documents-symbolic';
         else
-            iconName = 'x-office-document-symbolic';
+            iconName = 'org.gnome.Books-symbolic';
 
         this.add(new Gtk.Image({ pixel_size: 128, icon_name: iconName, margin_bottom: 9 }));
     },
@@ -294,18 +294,25 @@ const EmptyResultsBox = new Lang.Class({
     },
 
     _addSecondaryLabel: function() {
+        let label;
+        let useMarkup = false;
+
         if (this._mode == WindowMode.WindowMode.SEARCH) {
-            this.add(new Gtk.Label({ label: _("Try a different search") }));
-            return;
-        }
-
-        if (this._mode == WindowMode.WindowMode.COLLECTIONS) {
-            let label;
+            label = _("Try a different search");
+        } else if (this._mode == WindowMode.WindowMode.COLLECTIONS) {
             label = _("You can create collections from the Books view");
+        } else {
+            let docsPath, docsUrl;
 
-            this.add(new Gtk.Label({ label: label }));
-            return;
+            docsPath = GLib.get_user_special_dir(GLib.UserDirectory.DIRECTORY_DOCUMENTS);
+            docsUrl = Gio.file_new_for_path(docsPath).get_uri();
+            useMarkup = true;
+            /* translators: %s is the location of the Documents folder.*/
+            label = _('Books from your <a href="%s">Documents</a> folder will appear here').format(docsUrl);
         }
+
+        this.add(new Gtk.Label({ label: label,
+                                 use_markup: useMarkup }));
     }
 });
 
@@ -708,7 +715,8 @@ const OverviewToolbar = new Lang.Class({
             function(controller, count) {
                 this.toolbar.foreach(Lang.bind(this,
                     function(child) {
-                        child.set_sensitive(count != 0);
+                        if (child.name != 'menu-button')
+                            child.set_sensitive(count != 0);
                     }));
             }));
 
