@@ -588,10 +588,11 @@ var PreviewNavControls = new Lang.Class({
         this._overlay.add_overlay(this._prevRevealer);
 
         let prevButton = new Gtk.Button({ image: new Gtk.Image ({ icon_name: 'go-previous-symbolic',
-                                                                  pixel_size: 16 }), });
+                                                                  pixel_size: 16 }),
+                                          action_name: 'view.prev-page' });
+
         prevButton.get_style_context().add_class('osd');
         this._prevRevealer.add(prevButton);
-        prevButton.connect('clicked', Lang.bind(this, this._onPrevClicked));
         prevButton.connect('enter-notify-event', Lang.bind(this, this._onEnterNotify));
         prevButton.connect('leave-notify-event', Lang.bind(this, this._onLeaveNotify));
 
@@ -603,17 +604,18 @@ var PreviewNavControls = new Lang.Class({
         this._overlay.add_overlay(this._nextRevealer);
 
         let nextButton = new Gtk.Button({ image: new Gtk.Image ({ icon_name: 'go-next-symbolic',
-                                                                  pixel_size: 16 }) });
+                                                                  pixel_size: 16 }),
+                                          action_name: 'view.next-page' });
+
         nextButton.get_style_context().add_class('osd');
         this._nextRevealer.add(nextButton);
-        nextButton.connect('clicked', Lang.bind(this, this._onNextClicked));
         nextButton.connect('enter-notify-event', Lang.bind(this, this._onEnterNotify));
         nextButton.connect('leave-notify-event', Lang.bind(this, this._onLeaveNotify));
 
         this._prevRevealer.show_all();
         this._nextRevealer.show_all();
 
-        this._overlay.connect('motion-notify-event', Lang.bind(this, this._onMotion));
+        this._overlayMotionId = this._overlay.connect('motion-notify-event', Lang.bind(this, this._onMotion));
 
         this._tapGesture = new Gtk.GestureMultiPress({ propagation_phase: Gtk.PropagationPhase.CAPTURE,
                                                        touch_only: true,
@@ -636,6 +638,14 @@ var PreviewNavControls = new Lang.Class({
         return false;
     },
 
+    _removeMotionTimeout: function() {
+        if (this._motionId == 0)
+            return;
+
+        Mainloop.source_remove(this._motionId);
+        this._motionId = 0;
+    },
+
     _motionTimeout: function() {
         this._motionId = 0;
         this._visibleInternal = true;
@@ -668,14 +678,6 @@ var PreviewNavControls = new Lang.Class({
         this._tapGesture.set_state(Gtk.EventSequenceState.DENIED);
     },
 
-    _onPrevClicked: function() {
-        this.preview.goPrev();
-    },
-
-    _onNextClicked: function() {
-        this.preview.goNext();
-    },
-
     _autoHide: function() {
         this._autoHideId = 0;
         this._visibleInternal = false;
@@ -729,6 +731,14 @@ var PreviewNavControls = new Lang.Class({
     },
 
     destroy: function() {
+        this._unqueueAutoHide();
+        this._removeMotionTimeout();
+
+        if (this._overlayMotionId != 0) {
+            this._overlay.disconnect(this._overlayMotionId);
+            this._overlayMotionId = 0;
+        }
+
         if (this._barRevealer)
             this._barRevealer.destroy();
         this._prevRevealer.destroy();
